import{_ as u}from"./ItemsListing.vue_vue_type_style_index_0_lang-4412c609.js";import{_ as f,a as v}from"./ProviderDetails.vue_vue_type_script_setup_true_lang-204c118c.js";import{l as _,r as h,w,v as a,B as y,j as k,x as m,G as n,z as V,J as s,ak as g}from"./index-fa9c002a.js";import"./ListviewItem-c88d5d8d.js";import"./VBadge-21830be3.js";import"./ListItem-49546f89.js";import"./VImg-96d2a1b5.js";import"./VMenu-8f24ceef.js";import"./VCheckboxBtn-305cf49f.js";import"./VCard-045d27a9.js";import"./VTooltip-1568eef4.js";import"./PanelviewItem.vue_vue_type_style_index_0_lang-115f674a.js";import"./contextmenu-a25412d7.js";import"./Alert-1ee4728e.js";import"./Container-b7a21648.js";import"./VToolbar-5a04bbb8.js";import"./VTextField-bd0ececd.js";import"./VVirtualScroll-f9bb9f2e.js";import"./layout-d7f5b8fa.js";import"./VDialog-1f53ea62.js";const I=V("br",null,null,-1),K=_({__name:"RadioDetails",props:{itemId:{},provider:{}},setup(p){const t=p,e=h(),l=async function(){e.value=await s.getRadio(t.itemId,t.provider)};w(()=>t.itemId,i=>{i&&l()},{immediate:!0});const d=async function(i){const o=[];if(t.provider=="library"){const r=await s.getRadioVersions(t.itemId,t.provider);o.push(...r)}for(const r of g(e.value)){const c=await s.getRadioVersions(r.item_id,r.provider_instance);o.push(...c)}return o};return(i,o)=>(a(),y("section",null,[k(f,{item:e.value},null,8,["item"]),e.value?(a(),m(u,{key:0,itemtype:"radioversions","parent-item":e.value,"show-provider":!0,"show-favorites-only-filter":!1,"show-library":!1,"show-radio-number":!1,"show-duration":!1,"load-items":d,"sort-keys":["provider","sort_name"],title:i.$t("other_versions"),"hide-on-empty":!0,checksum:i.provider+i.itemId},null,8,["parent-item","title","checksum"])):n("",!0),I,e.value?(a(),m(v,{key:1,"item-details":e.value},null,8,["item-details"])):n("",!0)]))}});export{K as default};
